scoretools.make_pitch_array_score_from_pitch_arrays
===================================================

.. autofunction:: abjad.tools.scoretools.make_pitch_array_score_from_pitch_arrays.make_pitch_array_score_from_pitch_arrays
